Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(632)

Unified Diff: pkg/analyzer/lib/src/dart/analysis/library_context.dart

Issue 2682783002: Always add the target library to the store. (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/analyzer/lib/src/dart/analysis/analysis_impl.dart ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analyzer/lib/src/dart/analysis/library_context.dart
diff --git a/pkg/analyzer/lib/src/dart/analysis/library_context.dart b/pkg/analyzer/lib/src/dart/analysis/library_context.dart
index 2938decad6399df1b6d530df66f9ef585c566e0c..f14cde27a64211301cc16399f1e389b667f86208 100644
--- a/pkg/analyzer/lib/src/dart/analysis/library_context.dart
+++ b/pkg/analyzer/lib/src/dart/analysis/library_context.dart
@@ -37,10 +37,10 @@ class LibraryContext {
final AnalysisContext _analysisContext;
/**
* Create a [LibraryContext] which is prepared to analyze [library].
*/
factory LibraryContext.forSingleLibrary(
- FileState library,
+ FileState targetLibrary,
PerformanceLog logger,
PackageBundle sdkBundle,
ByteStore byteStore,
@@ -80,13 +80,13 @@ class LibraryContext {
}
logger.run('Append library files', () {
- return appendLibraryFiles(library);
+ return appendLibraryFiles(targetLibrary);
});
Set<String> libraryUrisToLink = new Set<String>();
logger.run('Load linked bundles', () {
for (FileState library in libraries.values) {
- if (library.exists) {
+ if (library.exists || library == targetLibrary) {
String key = '${library.transitiveSignature}.linked';
List<int> bytes = byteStore.get(key);
if (bytes != null) {
@@ -37,10 +37,10 @@ class LibraryContext {
final AnalysisContext _analysisContext;
/**
- * Create a [LibraryContext] which is prepared to analyze [library].
+ * Create a [LibraryContext] which is prepared to analyze [targetLibrary].
*/
factory LibraryContext.forSingleLibrary(
« no previous file with comments | « pkg/analyzer/lib/src/dart/analysis/analysis_impl.dart ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698